# new fusion test

Modulo usado apenas para testes e aprendizados sobre configurações e contribuições
em projetos open source

[![Build Status](https://travis-ci.com/AskaVictoria/fusion.svg?branch=main)](https://travis-ci.com/AskaVictoria/fusion)
[![Updates](https://pyup.io/repos/github/AdrianoKim/fusion/shield.svg)](https://pyup.io/repos/github/AdrianoKim/fusion/)
[![Python 3](https://pyup.io/repos/github/AdrianoKim/fusion/python-3-shield.svg)](https://pyup.io/repos/github/AdrianoKim/fusion/)



